@@ -13,8 +13,7 @@
  * more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __ONAK_H__
@@ -28,6 +27,8 @@ typedef enum {
 	ONAK_E_INVALID_PKT,
 	ONAK_E_UNKNOWN_VER,
 	ONAK_E_UNSUPPORTED_FEATURE,
+	ONAK_E_BAD_SIGNATURE,
+	ONAK_E_WEAK_SIGNATURE,
 } onak_status_t;
 
 #endif /* __ONAK_H__ */
